@@ -2,14 +2,29 @@ package Net::ISC::DHCPd::OMAPI;
 
 =head1 NAME
 
-Net::ISC::DHCPd::OMAPI - Talk to dhcp server
+Net::ISC::DHCPd::OMAPI - Talk to a dhcp server
+
+=head1 DESCRIPTION
+
+This module provides an API to query and possible change the ISC DHCPd
+server. The module use OMAPI (Object Management API) which does not
+require the server to be restarted for changes to apply.
+
+OMAPI is simply a communications mechanism that allows you to manipulate
+objects, which is stored in the dhcpd.leases file.
+
+See subclasses for more information about the different objects you can
+manipulate:
+L<Net::ISC::DHCPd::OMAPI::Failover>,
+L<Net::ISC::DHCPd::OMAPI::Group>,
+L<Net::ISC::DHCPd::OMAPI::Host>,
+and L<Net::ISC::DHCPd::OMAPI::Lease>.
 
 =head1 NOTE
 
- BEGIN {
-   Net::ISC::DHCPd::OMAPI::_DEBUG = sub { 1 }; # to enable debug output
-   use Net::ISC::DHCPd::OMAPI;
- }
+To enable debug output, execute this chunk of code before loading the module:
+
+ BEGIN { Net::ISC::DHCPd::OMAPI::_DEBUG = sub { 1 } }
 
 =cut
 
@@ -17,6 +32,7 @@ use Moose;
 use IO::Pty;
 use Time::HiRes qw/usleep/;
 use Net::ISC::DHCPd::OMAPI::Control;
+use Net::ISC::DHCPd::OMAPI::Failover;
 use Net::ISC::DHCPd::OMAPI::Group;
 use Net::ISC::DHCPd::OMAPI::Host;
 use Net::ISC::DHCPd::OMAPI::Lease;
@@ -265,7 +281,7 @@ sub new_object {
     my %args  = @_;
     my $class = "Net::ISC::DHCPd::OMAPI::" .ucfirst(lc $type);
 
-    unless($type =~ /^(?:control|group|host|lease)$/i) {
+    unless($type =~ /^(?:control|failover|group|host|lease)$/i) {
         return;
     }
 
