@@ -6,6 +6,9 @@ Net::ISC::DHCPd::OMAPI::Actions - Common actions on OMAPI objects
 
 =head1 DESCRIPTION
 
+This module contains methods which can be called on each of the
+L<Net::ISC::DHCPd::OMAPI> subclasses.
+
 Changing object attributes will not alter the attributes on server. To do
 so, either use L<set()> directly or use L<write()> after altering attributes.
 
@@ -13,12 +16,16 @@ so, either use L<set()> directly or use L<write()> after altering attributes.
 
 use Moose::Role;
 
+my $attr_role = "Net::ISC::DHCPd::OMAPI::Meta::Attribute";
+
 =head1 ATTRIBUTES
 
 =head2 parent
 
  $omapi_obj = $self->parent;
 
+Returns the parent L<Net::ISC::DHCPd::OMAPI> object.
+
 =cut
 
 has parent => (
@@ -31,6 +38,8 @@ has parent => (
 
  $str = $self->errstr;
 
+Holds the latest error. Check this if a method returns empty list.
+
 =cut
 
 has errstr => (
@@ -69,7 +78,8 @@ all unknown objects in L<extra_attributes>.
 
 sub read {
     my $self = shift;
-    my(@cmd, @out, $n);
+    my $n    = 0;
+    my @out;
 
     @out = $self->_open;
 
@@ -77,7 +87,8 @@ sub read {
 
     while($out[-1] =~ /(\S+)\s=\s(\S+)/g) {
         my($attr, $value) = ($1, $2);
-        $attr =~ s/-/_/g;
+        $attr  =~ s/-/_/g;
+        $value =~ s/^"(.*)"$/$1/;
         $n++;
 
         if($self->meta->has_attribute($attr)) {
@@ -108,40 +119,40 @@ attribute with action "modify" on update.
 sub write {
     my $self = shift;
     my @attr = @_;
-    my $new  = 1;
+    my $new = 0;
     my(@cmd, @out);
 
     # check for existence
     @out = $self->_open;
 
-    if($out[-1] =~ /(\S+)\s=\s(\S+)/g) {
-        $new = 0;
+    if(grep { /not found/i } @out) {
+        $new = 1;
     }
 
     if(@attr == 0) {
-        my $attr_role = "Net::ISC::DHCPd::OMAPI::Meta::Attribute";
         for my $attr ($self->meta->get_all_attributes) {
+            my $name = $attr->name;
+
             next if(!$attr->does($attr_role));
-            next if(!$attr->has_action('modify') and !$new);
-            next if($attr->has_action('modify') and !$new);
-            push @attr, $attr->name;
+            next if(!$self->${ \"has_$name" });
+            next if(!$attr->has_action('modify'));
+
+            push @attr, $attr;
         }
     }
 
-    for my $name (@attr) {
-        my $key = $name;
-        $key =~ s/_/-/g;
-        push @cmd, 'set %s = %s', $key, $self->$name;
-    }
+    @cmd = map { $self->_set_cmd($_) } @attr or return;
 
     # set attributes
     @out = $self->_cmd(@cmd);
 
-    # need to test @out
-    # ...
-
     # update or create
-    $self->_cmd( $new ? "create" : "update" ) or return;
+    @out = $self->_cmd( $new ? "create" : "update" ) or return;
+
+    if(grep { /not found/ } @out) {
+        $self->errstr("not found");
+        return;
+    }
 
     return $new ? +1 : -1;
 }
@@ -173,7 +184,7 @@ sub unset {
         $self->${ \"clear_$_" } for(@attr);
     }
 
-    return;
+    return 1;
 }
 
 around unset => \&_around;
@@ -182,24 +193,33 @@ around unset => \&_around;
 
  $bool = $self->remove;
 
+This method will remove the object from the server.
+
 =cut
 
 sub remove {
     my $self = shift;
-    my $pk   = $self->primary;
     my @out;
 
-    @out = $self->_cmd(
-               sprintf("set %s = %s", $pk, $self->$pk),
-               "remove",
-           );
+    @out = $self->_open;
+    @out = $self->_cmd('remove');
 
-    for my $attr ($self->meta->get_all_attributes) {
-        next unless($attr->has_value('omapi'));
-        $self->${ \"clear_" .$attr->name };
+    if(grep { /not implemented/i } @out) {
+        $self->errstr('not implemented');
+        return;
+    }
+    if(grep { /not found/i } @out) {
+        $self->errstr('not found');
+        return;
     }
 
-    return;
+    for my $attr ($self->meta->get_all_attributes) {
+        next unless($attr->does($attr_role));
+        my $clearer = 'clear_' .$attr->name;
+        $self->$clearer;
+    }
+
+    return 1;
 }
 
 around remove => \&_around;
@@ -211,31 +231,44 @@ sub _open {
 
     for my $name ($self->meta->get_attribute_list) {
         my $attr = $self->meta->get_attribute($name);
-        my $key = $name;
 
         next unless($attr->does("Net::ISC::DHCPd::OMAPI::Meta::Attribute"));
         next unless($attr->has_action("lookup"));
         next unless($self->${ \"has_$name" });
 
-        $key =~ s/_/-/g;
-
-        push @cmd, sprintf 'set %s = %s', $key, $self->$name;
+        push @cmd, $self->_set_cmd($attr);
     }
 
     return $self->_cmd(@cmd, "open");
 }
 
+sub _set_cmd {
+    my $self = shift;
+    my $attr = shift;
+    my $name = $attr->name;
+    my $key = $name;
+    my $format;
+
+    $key =~ s/_/-/g;
+    $format = $attr->type_constraint->equals('Str') ? 'set %s = "%s"'
+            :                                         'set %s = %s';
+
+    return sprintf $format, $key, $self->${ \"raw_$name" };
+}
+
 sub _around {
     my $next = shift;
     my $self = shift;
     my $type = lc +(ref($self) =~ /::(\w+)$/)[0];
     my(@out, @ret);
 
+    $self->errstr("");
+
     @out = $self->_cmd("new $type") or return 0;
-    @ret = $self->$next(@_)         or return 0;
+    @ret = $self->$next(@_);
     @out = $self->_cmd('close')     or return 0;
 
-    return @ret;
+    return @ret == 1 ? $ret[0] : @ret;
 };
 
 # @buffer = $self->_cmd(@cmd)
@@ -246,8 +279,6 @@ sub _cmd {
     my @cmd  = @_;
     my(@buffer, $head);
 
-    $self->errstr("");
-
     for my $cmd (@cmd) {
         my $tmp = $self->parent->_cmd($cmd);
         last unless(defined $tmp);
