@@ -17,12 +17,22 @@ use MooseX::Types;
 use MooseX::Types::Moose ':all';
 
 my @type_list;
-my @states = qw/na free active expired released
-                abandoned reset backup reserved bootp/;
+my @failover_states = (
+    "na",                     "partner down",
+    "normal",                 "communications interrupted",
+    "resolution interrupted", "potential conflict",
+    "recover",                "recover done",
+    "shutdown",               "paused",
+    "startup",                "recover wait",
+);
+my @states = qw/
+    na free active expired released
+    abandoned reset backup reserved bootp
+/;
 
 BEGIN {
     MooseX::Types->import(-declare => [@type_list = qw/
-        HexInt Ip Mac State Time Statements
+        HexInt Ip Mac State Time Statements FailoverState
         ConfigObject LeasesObject OMAPIObject ProcessObject
     /]);
 }
@@ -41,16 +51,57 @@ BEGIN {
 
 =cut
 
-subtype State, as Str, where { my $s = $_; return grep { $s eq $_ } @states };
+subtype State, as Str,
+    where { my $s = $_; return grep { $s eq $_ } @states };
+subtype FailoverState, as Str,
+    where { my $s = $_; return grep { $s eq $_ } @failover_states };
 subtype HexInt, as Int;
-subtype Ip, as Str, where { /^[\d.]+$/ };
-subtype Mac, as Str, where { /^[a-f0-9:]{17}$/i };
+subtype Ip, as Str,
+    where { /^[\d.]+$/ };
+subtype Mac, as Str,
+    where { /^[a-f0-9:]{17}$/i };
 subtype Time, as Int;
 
 coerce State, (
     from Str, via { /(\d+)$/ ? $states[$1] : undef }
 );
 
+=head2 from_State
+
+=cut
+
+sub from_State {
+    my $self = shift;
+    my $attr = shift;
+    my $value = $self->$attr || return 0;
+
+    for my $i (0..@states) {
+        return $i if($states[$i] eq $value);
+    }
+
+    return 0;
+}
+
+coerce FailoverState, (
+    from Str
+);
+
+=head2 from_FailoverState
+
+=cut
+
+sub from_FailoverState {
+    my $self = shift;
+    my $attr = shift;
+    my $value = $self->$attr || return 0;
+
+    for my $i (0..@failover_states) {
+        return $i if($failover_states[$i] eq $value);
+    }
+
+    return 0;
+}
+
 coerce HexInt, (
     from Str, via { s/://g; hex $_ },
 );
